@@ -45,14 +45,18 @@ using Beagle.Daemon;
 
 // Executors go in here.
 [assembly: RequestMessageExecutorTypes (
+	typeof (CountMatchQueryExecutor),
 	typeof (DaemonInformationExecutor),
 	typeof (InformationalMessagesRequestExecutor),
 	typeof (OptimizeIndexesExecutor),
 	typeof (QueryExecutor),
+#if ENABLE_RDF_ADAPTER
+	typeof (RDFQueryExecutor),
+#endif
 	typeof (ReloadConfigExecutor),
+	typeof (RemovableIndexExecutor),
 	typeof (ShutdownExecutor),
-	typeof (SnippetExecutor),
-	typeof (CountMatchQueryExecutor)
+	typeof (SnippetExecutor)
 )]
 
 // All backends in this assembly must be registered here.
