@@ -1,7 +1,7 @@
 //
 // QueryableFlavor.cs
 //
-// Copyright (C) 2004 Novell, Inc.
+// Copyright (C) 2004-2007 Novell, Inc.
 //
 
 //
@@ -33,5 +33,8 @@ namespace Beagle.Daemon {
 
 		public string      Name;
 		public QueryDomain Domain;
+		public bool        RequireInotify = true;
+		public bool        RequireExtendedAttributes = false;
+		public string      DependsOn;
 	}
 }
