@@ -99,4 +99,17 @@ namespace Beagle.Daemon {
 			return new EmptyResponse ();
 		}
 	}
+
+	[RequestMessage (typeof (RemovableIndexRequest))]
+	public class RemovableIndexExecutor : RequestMessageExecutor {
+		public override ResponseMessage Execute (RequestMessage req)
+		{
+			RemovableIndexRequest r = (RemovableIndexRequest) req;
+			bool to_mount = r.Mount;
+			string index_dir = r.IndexDir;
+			string mnt_dir = r.MountDir;
+
+			return QueryDriver.HandleRemovableIndexRequest (to_mount, index_dir, mnt_dir);
+		}
+	}
 }
